var NAVTREEINDEX10 =
{
"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[6,18,18],
"group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[6,18,67],
"group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[6,18,50],
"group__API__Workers.html#ga1552f16bc4b25d839efc732180efa130":[6,18,43],
"group__API__Workers.html#ga173d616aefe98c33a47a847fd2fca37d":[6,18,9],
"group__API__Workers.html#ga177bffe36c7df3f91aaebe2dd03b8cda":[6,18,2],
"group__API__Workers.html#ga178dd465219373d9da366fff593d56fa":[6,18,17],
"group__API__Workers.html#ga1c6e6bcceeb1c5d4edafa9d933d15cc2":[6,18,23],
"group__API__Workers.html#ga1c9cefba8ede1b63cef4a617a73f7d2c":[6,18,54],
"group__API__Workers.html#ga1d20d159f519df135fb1ac954a29bccf":[6,18,58],
"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9":[6,18,31],
"group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[6,18,13],
"group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[6,18,66],
"group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[6,18,68],
"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[6,18,49],
"group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[6,18,69],
"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[6,18,45],
"group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[6,18,32],
"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[6,18,22],
"group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[6,18,39],
"group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce":[6,18,38],
"group__API__Workers.html#ga40eea17cbbabcb0eed906d0b50604ed2":[6,18,63],
"group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[6,18,51],
"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[6,18,7],
"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[6,18,24],
"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[6,18,53],
"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[6,18,47],
"group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[6,18,59],
"group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[6,18,37],
"group__API__Workers.html#ga60b4a796a3dba40e5159158750805bf2":[6,18,25],
"group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a":[6,18,14],
"group__API__Workers.html#ga65ceee59fa79646aa5d2447eb2b17037":[6,18,11],
"group__API__Workers.html#ga6f3fbb6e918d0135ccb68473a8ee5ca1":[6,18,8],
"group__API__Workers.html#ga76d913164202fc836d6f76811371db0c":[6,18,71],
"group__API__Workers.html#ga7703495d0659819cef60634c1b704af2":[6,18,33],
"group__API__Workers.html#ga7de6654141ce89ea83c3aba60486396e":[6,18,52],
"group__API__Workers.html#ga80b06886ee8a4c0e99b09ab638113af3":[6,18,10],
"group__API__Workers.html#ga81227c4d4758d9f1b4a12cc3ecfc8a96":[6,18,55],
"group__API__Workers.html#ga832ce3b4d20a3f94da0d681965e8eea1":[6,18,41],
"group__API__Workers.html#ga8c4e370ff327c38a3ec79c9249ab233a":[6,18,15],
"group__API__Workers.html#ga8dc923de752528ca92c129c00af3703e":[6,18,70],
"group__API__Workers.html#ga9381b07c96aa7d1d0e6edeb338b2fd94":[6,18,29],
"group__API__Workers.html#ga95b8a935e52957f51659be8abad46668":[6,18,35],
"group__API__Workers.html#ga9b2541fc1a20c4c486c499af01a3283c":[6,18,60],
"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[6,18,5],
"group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[6,18,3],
"group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[6,18,19],
"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[6,18,4],
"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[6,18,27],
"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[6,18,12],
"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[6,18,65],
"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[6,18,61],
"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[6,18,57],
"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[6,18,40],
"group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[6,18,21],
"group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3":[6,18,16],
"group__API__Workers.html#gacdc94f67f203028dbfc25a2e8b588bb5":[6,18,62],
"group__API__Workers.html#gace5e9c1624f4d6449b22857b38326e9e":[6,18,73],
"group__API__Workers.html#gad3f993a7ab14f16e51406a7da3c634f2":[6,18,64],
"group__API__Workers.html#gad58c5fb79e34ec4bf2689213ee4528c3":[6,18,36],
"group__API__Workers.html#gad7c443d1341e4976d63fb5d77e74bf09":[6,18,6],
"group__API__Workers.html#gae1ab43056f2c28ed3826e80c5a86a0fc":[6,18,26],
"group__API__Workers.html#gae1ea590928704bb8578db76422c4022c":[6,18,72],
"group__API__Workers.html#gae35a841f996b8758f3d0ce2ac2d066a5":[6,18,30],
"group__API__Workers.html#gae5eabb8523f44bc9ac81031e05f99f66":[6,18,44],
"group__API__Workers.html#gae6166f338640d033b740f5c8008b851b":[6,18,28],
"group__API__Workers.html#gaec386585a6952f9c7fb47621844fbb39":[6,18,20],
"group__API__Workers.html#gaf48e8da13c523a7a9f2530349ddda29e":[6,18,56],
"group__API__Workers.html#gafc5f2fe263ec932eaf48ab0d313bc322":[6,18,42],
"group__API__Workers.html#gafcf67f47d1addfbe6ca143f04065b00c":[6,18,48],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da26ced4e9dfc43343f0b442bb465218a9":[6,18,9,1],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da5e57c05c04fb13b5383006cfb7719bf5":[6,18,9,4],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da6afc9f886af7206833d473e20d2343e7":[6,18,9,6],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da7fa269b896814504abcf227388233d1f":[6,18,9,0],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dac8fa4358a1bbed68129ebc834ee32bc1":[6,18,9,3],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dad2e8eb63bb5c17adcf205af07deff98c":[6,18,9,2],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadbf5857b92809e4c81cc7a8b4f7d34c3":[6,18,9,8],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadc9efedf9b6e4e6ce71d8522f6c1206f":[6,18,9,7],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37daf5a63ea6a5480c1a6bcf65db1a4c8761":[6,18,9,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a0f41ef0eff3429abe8480b285c8e37d9":[6,18,8,8],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a25ef72894680c188a842f2cefebeb673":[6,18,8,7],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a30be863a2bfc1c5b98c9f2ccdf62394a":[6,18,8,6],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a3bb8e78a9fffd443b2e87d648a1c7531":[6,18,8,3],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a4f0b10cf4c5fb6333b9e3906b81cc5a6":[6,18,8,1],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af":[6,18,8,4],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aa081477174eb3510759873f06bf5f585":[6,18,8,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1ad203062edfbde734600e982a54fe5ad2":[6,18,8,9],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1adba8e3eb8cbe7ba83bbd4c1707fc5ffd":[6,18,8,0],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aeb7a39d95a8ff63c3d7e1fc479fe923f":[6,18,8,2],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a2542d005328b674a7479c0c49068f914":[6,18,10,0],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a574a8ee7f0fc8414cd16767c88481d26":[6,18,10,1],
"group__API__Workers.html#structstarpu__sched__ctx__iterator":[6,18,0],
"group__API__Workers.html#structstarpu__worker__collection":[6,18,1],
"index.html":[],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[8,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[7,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[8,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[8,0,0,2],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[7,0,0,2],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[8,0,0,3],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[8,0,0,4],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[7,0,0,4],
"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[7,0,0,5],
"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[8,0,0,5],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[8,0,0,6],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[8,0,0,7],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[7,0,0,7],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[7,0,0,8],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[8,0,0,8],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[8,0,0,9],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[7,0,0,9],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[8,0,0,10],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[7,0,0,10],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[8,0,0,11],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[7,0,0,11],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[8,0,0,12],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[7,0,0,12],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[8,0,0,13],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[7,0,0,13],
"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[7,0,0,14],
"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[8,0,0,14],
"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[8,0,0,15],
"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[7,0,0,15],
"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[7,0,0,16],
"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[8,0,0,16],
"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[7,0,0,17],
"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[8,0,0,17],
"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[7,0,0,18],
"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[8,0,0,18],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[8,0,0,19],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[7,0,0,19],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[7,0,0,20],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[8,0,0,20],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[8,0,0,21],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[7,0,0,21],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[7,0,0,22],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[8,0,0,22],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[7,0,0,23],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[8,0,0,23],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[7,0,0,24],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[8,0,0,24],
"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[7,0,0,25],
"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[8,0,0,25],
"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[7,0,0,26],
"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[8,0,0,26],
"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[8,0,0,27],
"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[7,0,0,27],
"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[8,0,0,28],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[7,0,0,29],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[8,0,0,29],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[8,0,0,30],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[7,0,0,31],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[8,0,0,31],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[7,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[8,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[7,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[8,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[8,0,0,34],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[7,0,0,34],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[8,0,0,35],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[7,0,0,35],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[8,0,0,36],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[7,0,0,36],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[8,0,0,37],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[7,0,0,38],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[8,0,0,38],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[8,0,0,39],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[7,0,0,39],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[8,0,0,40],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[7,0,0,40],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[8,0,0,41],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[7,0,0,41],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[8,0,0,42],
"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[7,0,0,42],
"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[8,0,0,43],
"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[7,0,0,43],
"interfacefstarpu__mod_1_1fstarpu__conf__free.html":[7,0,0,44],
"interfacefstarpu__mod_1_1fstarpu__conf__free.html":[8,0,0,44],
"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[8,0,0,45],
"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[7,0,0,45],
"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[8,0,0,46],
"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[7,0,0,46],
"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[8,0,0,47],
"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[7,0,0,47],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[8,0,0,48],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[7,0,0,48],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[8,0,0,49],
"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[7,0,0,49],
"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[8,0,0,50],
"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[7,0,0,50],
"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[8,0,0,51],
"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[7,0,0,51],
"interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[8,0,0,52],
"interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[7,0,0,52],
"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[7,0,0,53],
"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[8,0,0,53],
"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[8,0,0,54],
"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[7,0,0,54],
"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[7,0,0,55],
"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[7,0,0,56],
"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[7,0,0,57],
"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[7,0,0,59],
"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[7,0,0,60],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[7,0,0,62],
"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,63],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,71],
"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,72],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,73],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,74],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,75],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,76],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77]
};
